Adjust clang format to the new versions, revert broken macro layout (#714)
Этот коммит содержится в:
коммит произвёл
GitHub
родитель
ed877433f3
Коммит
2ff2316227
@@ -32,5 +32,5 @@ __device__ int getSquareOfGlobalFloat() {
|
||||
extern "C" __global__ void testWeightedCopy(int* a, int* b) {
|
||||
int tx = threadIdx.x;
|
||||
b[tx] = deviceGlobalInt1 * a[tx] + deviceGlobalInt2 + static_cast<int>(deviceGlobalShort) +
|
||||
static_cast<int>(deviceGlobalChar) + getSquareOfGlobalFloat();
|
||||
static_cast<int>(deviceGlobalChar) + getSquareOfGlobalFloat();
|
||||
}
|
||||
|
||||
Ссылка в новой задаче
Block a user